django-publish - cli publishing for ``django-articles`` blogs
=============================================================

``django-publish`` allows you to publish to your ``django-articles``-powered
blog via the command line. Currently only supports documents written in reST
(though why would you use anything else?! ;)). For more information, consult the
`documentation`_.

.. _documentation: http://docs.recursivedream.com/django-publish/

Credits
-------

- `django-articles`_

.. _django-articles: http://github.com/codekoala/django-articles/
